import React from 'react';
import createAccountAdapter from '~/driven/adapters/create-account-adapter/createAccountAdapter';
import createProfileAdapter from '~/driven/adapters/create-profile-adapter/createProfileAdapter';
import CreateUserInfra from '~/business-logic/core/users/create-user';
import CreateUserView from '../view/CreateUserView';
import useCreateUserVM from '../viewmodel/CreateUserVM';
import createUserModel from '../model/createUserModel';

export default function CreateUser() {
  // get adapters from driven layer
  const createAccountDrivenAdapter = createAccountAdapter();
  const createProfileDrivenAdapter = createProfileAdapter();
  // pass to the logic and get the usecase
  const createUserInfra = new CreateUserInfra(createAccountDrivenAdapter, createProfileDrivenAdapter);
  const createUserLogic = createUserInfra.execute();
  // pass the usecase to the model
  const { handleSubmitForm } = createUserModel({ createUserLogic });
  // pass the method to the viewmodel to call on submit
  const { stateHandler, onSubmit, inputNames } = useCreateUserVM({ handleSubmitForm });
  // get all of the needed information to the user to show
  return <CreateUserView stateHandler={stateHandler} inputNames={inputNames} onSubmit={onSubmit} />;
}
