import { useState } from 'react';
import { checkPhoneNumberInput } from '~/driven/utils/helpers/globalHelpers';
import { INewUserData } from '~/business-logic/core/users/create-user/create-account/data/dto/protocols';
import ICreateUserViewProps from '../view/protocols';
import IUseCreateUserVm from './protocols';

const inputStateInitialValue: INewUserData = {
  firstname: '',
  lastname: '',
  phonenumber: '',
};

const inputNames: (keyof INewUserData)[] = ['firstname', 'lastname', 'phonenumber'];

const useCreateUserVM = (dependencies: IUseCreateUserVm): ICreateUserViewProps => {
  const { handleSubmitForm } = dependencies;
  const [inputsValue, setInputValues] = useState<INewUserData>(inputStateInitialValue);

  const inputsSetStates = (name: keyof INewUserData, newValue: string) => {
    if (name === 'phonenumber' && !checkPhoneNumberInput(newValue)) return;
    setInputValues((prev) => ({
      ...prev,
      [name]: newValue,
    }));
  };

  const onSubmitCreateUserForm = (e: React.FormEvent) => {
    e.preventDefault();
    console.log('submit user', inputsValue);
    handleSubmitForm(inputsValue);
  };

  const inputStates: INewUserData = { ...inputsValue };

  return {
    stateHandler: {
      inputsSetStates,
      inputStates,
    },
    onSubmit: onSubmitCreateUserForm,
    inputNames,
  };
};

export default useCreateUserVM;
