/* eslint-disable @typescript-eslint/no-unused-vars */
import React, { useMemo } from 'react';
import { staticMessages } from '~/driven/utils/constants/staticMessages';
import Users from '~/business-logic/core/users/common/entity/entity';
import Loading from '~/driven/utils/components/loading/Loading';
import TableRow from '../../common/table-row';
import { IUserListProps } from './protocols';

export default function UsersListView(props: IUserListProps) {
  const { selectedRowId, setSelectedRowId, usersList } = props;
  const rows = useMemo(() => {
    if (!usersList.data) return null;

    return usersList.data.getData().map((user) => {
      const rowData = {
        rowItemsTitle: [user.firstname, user.lastname],
        rowId: user.accountId,
      };
      return (
        <TableRow
          key={rowData.rowId}
          rowData={rowData}
          selectedRowId={selectedRowId}
          setSelectedRowId={setSelectedRowId}
        />
      );
    });
  }, [usersList]);
  const tableTitles: Pick<Users, 'firstname' | 'lastname'> = {
    firstname: staticMessages.global.firstname,
    lastname: staticMessages.global.lastname,
  };

  const titles = Object.keys(tableTitles).map((titleKey) => {
    const key = titleKey as keyof typeof tableTitles;

    const title = tableTitles[key];
    return (
      <th key={key} className='py-3'>
        {title}
      </th>
    );
  });

  if (usersList.isLoading)
    return (
      <div className='flex justify-center items-center'>
        <Loading />
      </div>
    );

  return (
    <table className='table-auto rounded-md w-full text-sm h-fit'>
      <thead className='text-txt-medium font-bold'>
        <tr>{titles}</tr>
      </thead>
      <tbody>{rows}</tbody>
    </table>
  );
}
